# swaystatus

Generate a status line for [swaybar][swaybar-protocol].

## Installation

### Python

Install as a python package:

```sh
pip install swaystatus
```

### Arch User Repository (AUR)

There are two packages available for Arch Linux, available via the AUR.

Stable, based on the latest tagged release: [swaystatus][pkg-aur]

Unstable, based on the latest commit to the main branch: [swaystatus-git][pkg-aur-git]

## Usage

See `pydoc swaystatus` for details on package usage.

See `swaystatus --help` for command line interface help.

See [sway-bar(5)][sway-bar] for details on setting `status_command`.

See [swaybar-protocol(7)][swaybar-protocol] for a definition of the status bar protocol.

[pkg-aur]: https://aur.archlinux.org/packages/swaystatus/
[pkg-aur-git]: https://aur.archlinux.org/packages/swaystatus-git/
[sway-bar]: https://man.archlinux.org/man/extra/sway/sway-bar.5.en
[swaybar-protocol]: https://man.archlinux.org/man/swaybar-protocol.7
